pub struct DestinationField {
pub name: String,
pub data_type: String,
}Fields
name: Stringdata_type: StringTrait Implementations
Sourceimpl Clone for DestinationField
impl Clone for DestinationField
Sourceimpl Debug for DestinationField
impl Debug for DestinationField
Sourceimpl<'de> Deserialize<'de> for DestinationField
impl<'de> Deserialize<'de> for DestinationField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DestinationField
impl JsonSchema for DestinationField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DestinationField
impl RefUnwindSafe for DestinationField
impl Send for DestinationField
impl Sync for DestinationField
impl Unpin for DestinationField
impl UnsafeUnpin for DestinationField
impl UnwindSafe for DestinationField