pub struct PrimaryKeySpec {
pub logic: PrimaryKeyLogic,
pub keys: Vec<String>,
}Fields
logic: PrimaryKeyLogickeys: Vec<String>Trait Implementations
Sourceimpl Clone for PrimaryKeySpec
impl Clone for PrimaryKeySpec
Sourceimpl Debug for PrimaryKeySpec
impl Debug for PrimaryKeySpec
Sourceimpl<'de> Deserialize<'de> for PrimaryKeySpec
impl<'de> Deserialize<'de> for PrimaryKeySpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PrimaryKeySpec
impl JsonSchema for PrimaryKeySpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PrimaryKeySpec
impl RefUnwindSafe for PrimaryKeySpec
impl Send for PrimaryKeySpec
impl Sync for PrimaryKeySpec
impl Unpin for PrimaryKeySpec
impl UnsafeUnpin for PrimaryKeySpec
impl UnwindSafe for PrimaryKeySpec