pub struct SourceFieldSpec {
pub id: String,
pub source_file_id: String,
pub column_name: String,
}Fields
id: Stringsource_file_id: Stringcolumn_name: StringTrait Implementations
Sourceimpl Clone for SourceFieldSpec
impl Clone for SourceFieldSpec
Sourceimpl Debug for SourceFieldSpec
impl Debug for SourceFieldSpec
Sourceimpl<'de> Deserialize<'de> for SourceFieldSpec
impl<'de> Deserialize<'de> for SourceFieldSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SourceFieldSpec
impl JsonSchema for SourceFieldSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SourceFieldSpec
impl RefUnwindSafe for SourceFieldSpec
impl Send for SourceFieldSpec
impl Sync for SourceFieldSpec
impl Unpin for SourceFieldSpec
impl UnsafeUnpin for SourceFieldSpec
impl UnwindSafe for SourceFieldSpec